<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Plugin activeren',
	'affichage' => 'Weergave',
	'aide_non_disponible' => 'Dit deel van de online handleiding is nog niet beschikbaar in het Nederlands.',
	'annuler_recherche' => 'Zoekopdracht stoppen',
	'auteur' => 'Auteur:',
	'avis_acces_interdit' => 'Toegang verboden',
	'avis_acces_interdit_prive' => 'Je hebt geen toegangsrechten voor pagina <b>@exec@</b>.',
	'avis_article_modifie' => 'LET OP: @nom_auteur_modif@ heeft @date_diff@ minuten geleden aan dit artikel gewerkt.',
	'avis_aucun_resultat' => 'Geen resultaat.',
	'avis_base_inaccessible' => 'Kan geen verbinding maken met database @base@.',
	'avis_chemin_invalide_1' => 'De toegang die je hebt gekozen',
	'avis_chemin_invalide_2' => 'lijkt niet geldig. Ga terug naar de vorige pagina en controleer de ingevulde gegevens.',
	'avis_connexion_echec_1' => 'De verbinding met de database is mislukt.',
	'avis_connexion_echec_2' => 'Keer terug naar de vorige pagina en kijk de gegevens na die je hebt ingevuld.',
	'avis_connexion_echec_3' => '<b>LET OP</b> Op veel servers moet je vooraf om activatie van je toegang tot de database <b>vragen</b>. Als je geen verbinding kan maken, kijk dan na of je deze actie hebt ondernomen.',
	'avis_connexion_erreur_creer_base' => 'De database kon niet worden gemaakt.',
	'avis_connexion_erreur_nom_base' => 'De databasenaam kan enkel letters, cijfers en koppeltekens bevatten',
	'avis_connexion_ldap_echec_1' => 'De verbinding met de LDAP-server is mislukt.',
	'avis_connexion_ldap_echec_2' => 'Ga terug naar de vorige pagina en kijk na of de ingevulde gegevens correct zijn.',
	'avis_connexion_ldap_echec_3' => 'Andere mogelijkheid is om de LDAP-ondersteuning om gebruikers in te voeren niet te gebruiken.', # MODIF
	'avis_deplacement_rubrique' => 'LET OP! Deze rubriek bevat @contient_breves@ nieuwsflits@scb@. Als je wil verplaatsten, bevestig dit dan door hier het vakje aan te vinken.',
	'avis_erreur_connexion_mysql' => 'Verbinding met de SQL connectie mislukt',
	'avis_espace_interdit' => '<b>Toegang verboden</b><div>SPIP is al geïnstalleerd.</div>',
	'avis_lecture_noms_bases_1' => 'Het installatieprogramma heeft de namen van de geïnstalleerde databases niet kunnen lezen.',
	'avis_lecture_noms_bases_2' => 'Geen enkele database is beschikbaar, ofwel is de functie die de databases zou moeten tonen om veiligheidsredenen niet geactiveerd (wat vaak het geval is bij providers).',
	'avis_lecture_noms_bases_3' => 'In het andere geval is het heel waarschijnlijk dat een database met jouw aanmeldingsnaam (login) bruikbaar is:',
	'avis_non_acces_page' => 'Je hebt geen toegang tot deze pagina.',
	'avis_operation_echec' => 'De bewerking is mislukt.',
	'avis_operation_impossible' => 'Onmogelijke handeling',
	'avis_suppression_base' => 'LET OP: Het wissen van de gegevens is onomkeerbaar',

	// B
	'bouton_acces_ldap' => 'LDAP toegang toevoegen',
	'bouton_ajouter' => 'Toevoegen',
	'bouton_annuler' => 'Annuleren',
	'bouton_cache_activer' => 'Buffer (cache) reactiveren',
	'bouton_cache_desactiver' => 'Buffer (cache) tijdelijk uitschakelen',
	'bouton_demande_publication' => 'De publicatie van het artikel vragen',
	'bouton_desactive_tout' => 'Alles deactiveren',
	'bouton_desinstaller' => 'Terugtrekken',
	'bouton_effacer_tout' => 'ALLES wissen',
	'bouton_envoyer_message' => 'Definitief bericht: versturen',
	'bouton_fermer' => 'Sluiten',
	'bouton_mettre_a_jour' => 'Bijwerken',
	'bouton_mettre_a_jour_base' => 'Database update',
	'bouton_modifier' => 'Wijzigen',
	'bouton_radio_afficher' => 'Weergeven',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Opnemen in de lijst van online redacteurs', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Aankondigingen verzenden naar dit adres:',
	'bouton_radio_envoi_liste_nouveautes' => 'De lijst met nieuwe bijdragen versturen',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Niet opnemen in de lijst van redacteurs', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Geen editoriale aankondigingen versturen',
	'bouton_redirection' => 'OMLEIDING',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Terugzetten naar de standaardwaardes',
	'bouton_relancer_installation' => 'Installatie herstarten',
	'bouton_reset_password' => 'Een nieuw wachtwoord genereren en per email opsturen',
	'bouton_suivant' => 'Volgende',
	'bouton_tenter_recuperation' => 'Poging tot herstel',
	'bouton_test_proxy' => 'Proxy proberen',
	'bouton_vider_cache' => 'De buffer (cache) leegmaken',

	// C
	'cache_modifiable_webmestre' => 'Deze parameter kan door de webmaster van de site gewijzigd worden.', # MODIF
	'calendrier_synchro' => 'Wanneer je <b>iCal</b> compatibele agendasoftware gebruikt, kan je deze synchroniseren met informatie van deze site.',
	'config_activer_champs' => 'De volgende velden activeren',
	'config_choix_base_sup' => 'een database op deze server kiezen',
	'config_erreur_base_sup' => 'SPIP heeft geen toegang tot de lijst van toegankelijke databases',
	'config_info_base_sup' => 'Als je andere databases hebt om door SPIP te ondervragen, met zijn SQL server of anders, kan je deze via onderstaand formulier opgeven. Als je bepaalde velden leeg laat, zullen de identificatiegegevens van de primaire database gebruikt worden.',
	'config_info_base_sup_disponibles' => 'De reeds opvraagbare aanvullende databases:',
	'config_info_enregistree' => 'De nieuwe configuratie werd bewaard',
	'config_info_logos' => 'Elk element van de site kan een logo hebben, evenals een « zwevend logo »',
	'config_info_logos_utiliser' => 'Logo’s gebruiken',
	'config_info_logos_utiliser_non' => 'Logo’s niet gebruiken',
	'config_info_logos_utiliser_survol' => 'Zwevende logo’s gebruiken',
	'config_info_logos_utiliser_survol_non' => 'Geen zwevende logo’s gebruiken',
	'config_info_redirection' => 'Door deze optie te activeren, kan je virtuele artikelen maken, eenvoudige verwijzen naar gepubliceerde artikelen op andere sites, ook buiten SPIP.',
	'config_redirection' => 'Virtuele artikelen',
	'config_titre_base_sup' => 'Declareren van een extra database',
	'config_titre_base_sup_choix' => 'Kies een extra database',
	'connexion_ldap' => 'Aansluiten:',
	'creer_et_associer_un_auteur' => 'Maken en associëren een auteur',

	// D
	'date_mot_heures' => 'uur',

	// E
	'ecran_securite' => '+ beveiligingsscherm @version@',
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'en_savoir_plus' => 'Meer weten hierover',
	'entree_adresse_annuaire' => 'Plaats van het adresboek',
	'entree_adresse_email' => 'Je e-mailadres',
	'entree_adresse_email_2' => 'E-mailadres',
	'entree_base_donnee_1' => 'Adres van de database',
	'entree_base_donnee_2' => '(Vaak komt dit adres overeen met dat van je website, soms is het gewoon de vermelding «localhost» of kan je het veld blanco laten.)',
	'entree_biographie' => 'Korte biografie in enkele woorden.',
	'entree_chemin_acces' => '<b>Invullen</b> van de toegangscode :',
	'entree_cle_pgp' => 'Je PGP-sleutel',
	'entree_cle_pgp_2' => 'PGP-sleutel',
	'entree_contenu_rubrique' => '(Inhoud van de rubriek in enkele woorden)',
	'entree_identifiants_connexion' => 'Je verbindingsgegevens...',
	'entree_identifiants_connexion_2' => 'Login',
	'entree_informations_connexion_ldap' => 'Vul hier de gegevens in om verbinding te maken met het LDAP adresboek. Deze gegevens kan je opvragen bij de systeem- of netwerkbeheerder.', # MODIF
	'entree_infos_perso' => 'Wie ben je ?',
	'entree_infos_perso_2' => 'Wie is de auteur ?',
	'entree_interieur_rubrique' => 'In de rubriek:',
	'entree_liens_sites' => '<b>Hypertext link</b> (verwijzing, te bezoeken website ...)',
	'entree_login' => 'Je login',
	'entree_login_connexion_1' => 'De login voor de verbinding',
	'entree_login_connexion_2' => '(Komt soms overeen met je FTP-loginnaam; soms wordt dit niet ingevuld)',
	'entree_mot_passe' => 'Je wachtwoord',
	'entree_mot_passe_1' => 'Wachtwoord voor deze verbinding ',
	'entree_mot_passe_2' => '(Komt vaak overeen met je wachtwoord voor FTP-toegang; soms kan je dit ook blanco laten)',
	'entree_nom_fichier' => 'Vul hier de naam in van het bestand @texte_compresse@:',
	'entree_nom_pseudo' => 'je naam of bijnaam',
	'entree_nom_pseudo_1' => '(Je naam of bijnaam)',
	'entree_nom_pseudo_2' => 'Naam of bijnaam',
	'entree_nom_site' => 'De websitenaam',
	'entree_nom_site_2' => 'Naam van de site van de auteur',
	'entree_nouveau_passe' => 'Nieuw wachtwoord',
	'entree_passe_ldap' => 'Wachtwoord',
	'entree_port_annuaire' => 'Het poortnummer van het adresboek',
	'entree_signature' => 'Handtekening',
	'entree_titre_obligatoire' => '<b>Titel</b> [verplicht]<br />',
	'entree_url' => 'Je website-adres (URL)',
	'entree_url_2' => 'Adres van de site (URL)',
	'erreur_connect_deja_existant' => 'Een server met die naam bestaat al',
	'erreur_contenu_suspect' => 'Slecht opgebouwde tekst',
	'erreur_email_deja_existant' => 'Dit emailadres is al geregistreerd.',
	'erreur_nom_connect_incorrect' => 'Deze server naam is niet toegestaan',
	'erreur_plugin_attribut_balise_manquant' => 'Attribuut @attribut@ ontbreekt in lus @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'Het verwijderen van de plugin is mislukt. Maar je kunt hem wel uitschakelen.',
	'erreur_plugin_fichier_absent' => 'Bestand ontbreekt',
	'erreur_plugin_fichier_def_absent' => 'Definitiebestand ontbreekt',
	'erreur_plugin_nom_fonction_interdit' => 'Functienaam verboden',
	'erreur_plugin_nom_manquant' => 'Naam van de ontbrekende plugin',
	'erreur_plugin_prefix_manquant' => 'Ruimte voor de naamgeving van de plugin is niet gedefinieerd',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; ontbreekt in het definitiebestand',
	'erreur_plugin_version_manquant' => 'Versie van de ontbrekende plugin',

	// H
	'htaccess_a_simuler' => 'Waarschuwing: De configuratie van de HTTP-server negeert @htaccess@ bestanden. Om een goede beveiliging te hebben, moet je deze configuratie wijzigen, of de constanten @constantes@ (definieerbaar in het bestand mes_options.php) laten verwijzen naar mappen buiten @document_root@. ', # Je ne vois pas la modif ! La trad reste valable.
	'htaccess_inoperant' => 'htaccess werkt niet',

	// I
	'ical_info1' => 'Deze pagina toont de verschillende wijzen waarop je contact kan houden met het gebeuren van deze website.',
	'ical_info2' => 'Voor meer inlichtingen over al deze technieken, aarzelt niet om <a href=" @spipnet@" te raadplegen >de documentatie van SPIP</a>.',
	'ical_info_calendrier' => 'Twee kalenders zijn beschikbaar. De eerste geeft een overzicht van alle gepubliceerde artikelen. De tweede bevat editoriale berichten en je meest recente privé-berichten : deze tweede kalender is afgeschermd voor andere gebruikers door een persoonlijke sleutel die je op elk moment kan wijzigen door je wachtwoord te vernieuwen.',
	'ical_methode_http' => 'Downloaden',
	'ical_methode_webcal' => 'Synchronisatie (webcal://)',
	'ical_texte_prive' => 'Deze kalender is voor persoonlijk gebruik en houdt je op de hoogte van je eigen editoriale activiteit (taken en persoonlijke afspraken, voorgestelde artikelen en nieuwsflitsen...).',
	'ical_texte_public' => 'Via deze kalender kan je de publieke activiteit van de site volgen (gepubliceerde artikelen en nieuwsflitsen).',
	'ical_texte_rss' => 'Je kan de nieuwe berichten van de site overnemen (syndiceren) op een andere site in eender welke bestandslezer via het formaat XML/RSS (Rich Site Summary). Dit is hetzelfde formaat dat SPIP toelaat nieuws over te nemen van andere sites die een uitwisselbaar formaat hanteren (gesyndiceerde sites).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailinglijst',
	'ical_titre_rss' => 'Syndicatiebestanden',
	'icone_accueil' => 'Home',
	'icone_activer_cookie' => 'De toegangskoekie activeren',
	'icone_activite' => 'Activiteit',
	'icone_admin_plugin' => 'Plugin beheer',
	'icone_administration' => 'Beheer',
	'icone_afficher_auteurs' => 'Auteurs tonen',
	'icone_afficher_visiteurs' => 'Bezoekers tonen',
	'icone_arret_discussion' => 'Niet langer deelnemen aan deze discussie',
	'icone_calendrier' => 'Kalender',
	'icone_configuration' => 'Configuratie',
	'icone_creer_auteur' => 'Een nieuwe auteur aanmaken en koppelen aan dit artikel',
	'icone_creer_mot_cle' => 'Een nieuw trefwoord aanmaken en koppelen aan dit artikel',
	'icone_creer_rubrique_2' => 'Een nieuwe rubriek aanmaken',
	'icone_developpement' => 'Ontwikkeling',
	'icone_edition' => 'Items',
	'icone_ma_langue' => 'Mijn taal',
	'icone_mes_infos' => 'Mijn informatie',
	'icone_mes_preferences' => 'Mijn Voorkeuren',
	'icone_modifier_article' => 'Dit artikel wijzigen',
	'icone_modifier_rubrique' => 'Deze rubriek wijzigen',
	'icone_publication' => 'Publicatie',
	'icone_relancer_signataire' => 'De ondertekenaar heractiveren',
	'icone_retour' => 'Terug',
	'icone_retour_article' => 'Terug naar artikel',
	'icone_squelette' => 'Skeletten',
	'icone_suivi_publication' => 'Publicaties volgen',
	'icone_supprimer_cookie' => 'De toegangskoekie verwijderen',
	'icone_supprimer_rubrique' => 'Deze rubriek wissen',
	'icone_supprimer_signature' => 'Deze naam wissen',
	'icone_valider_signature' => 'Deze naam goedkeuren',
	'image_administrer_rubrique' => 'Je kan deze rubriek beheren',
	'impossible_modifier_login_auteur' => 'De login kan niet worden veranderd.',
	'impossible_modifier_pass_auteur' => 'Het wachtwoord kan niet worden gewijzigd.',
	'info_1_article' => '1 artikel',
	'info_1_auteur' => '1 auteur',
	'info_1_message' => '1 bericht',
	'info_1_mot_cle' => '1 trefwoord',
	'info_1_rubrique' => '1 rubriek',
	'info_1_visiteur' => '1 bezoeker',
	'info_activer_cookie' => 'Je kan een <b>toegangskoekie</b> activeren, waardoor je makkelijk kan wisselen tussen de het publieke en het privé gedeelte van de website.',
	'info_activer_menu_developpement' => 'Toon het menu Ontwikkeling',
	'info_admin_etre_webmestre' => 'Geef me de webmaster rechten',
	'info_admin_je_suis_webmestre' => 'Ik ben <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Geef deze beheerder webmaster rechten', # MODIF
	'info_admin_webmestre' => 'Deze beheerder is <b>webmaster</b>', # MODIF
	'info_administrateur' => 'Beheerder', # MODIF
	'info_administrateur_1' => 'Beheerder', # MODIF
	'info_administrateur_2' => 'van de website (<i>voorzichtig gebruiken</i>)',
	'info_administrateur_site_01' => 'Als je beheerder bent van deze site, gelieve', # MODIF
	'info_administrateur_site_02' => 'deze koppeling aan te klikken',
	'info_administrateurs' => 'Beheerders', # MODIF
	'info_administrer_rubrique' => 'Je kan deze rubriek beheren',
	'info_adresse' => 'aan/naar het adres:',
	'info_adresse_desinscription' => 'Adres voor uitschrijven:',
	'info_adresse_url' => 'Adres (URL) van de website',
	'info_afficher_par_nb' => 'Tonen',
	'info_aide_en_ligne' => 'ONLINE HELP VAN SPIP',
	'info_ajout_image' => 'Als je afbeeldingen als bijlage aan een document toevoegt, kan SPIP hiervan automatisch miniaturen aanmaken. Hierdoor kan je bvb. automatisch een fotogalerij of portfolio aanmaken.
',
	'info_ajouter_rubrique' => 'Een nieuwe rubriek toevoegen om te beheren:',
	'info_annonce_nouveautes' => 'Aankondiging van nieuwe bijdragen',
	'info_article' => 'artikel',
	'info_article_2' => 'artikelen',
	'info_article_a_paraitre' => 'Te publiceren artikelen met postdatering',
	'info_articles_02' => 'artikelen',
	'info_articles_2' => 'Artikelen',
	'info_articles_auteur' => 'Artikelen van deze auteur',
	'info_articles_miens' => 'Mijn artikelen',
	'info_articles_tous' => 'Alle artikelen',
	'info_articles_trouves' => 'Gevonden artikelen',
	'info_attente_validation' => 'Je artikelen die op goedkeuring wachten',
	'info_aucun_article' => 'Geen artikelen',
	'info_aucun_auteur' => 'Geen auteur',
	'info_aucun_message' => 'Geen bericht',
	'info_aucun_rubrique' => 'Geen rubriek',
	'info_aujourdhui' => 'vandaag:',
	'info_auteur_gere_rubriques' => 'Deze auteur beheert de volgende rubrieken:',
	'info_auteur_gere_toutes_rubriques' => 'Deze auteur beheert <b>alle rubrieken</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Ik beheer <b>alle rubrieken</b>',
	'info_auteurs' => 'De auteurs',
	'info_auteurs_par_tri' => 'Auteur@partri@',
	'info_auteurs_trouves' => 'Gevonden auteurs',
	'info_authentification_externe' => 'Externe authenticatie',
	'info_avertissement' => 'Waarschuwing',
	'info_barre_outils' => 'met zijn gereedschapsbalk?',
	'info_base_installee' => 'De structuur van je database is geïnstalleerd.',
	'info_bio' => 'biografie',
	'info_cache_desactive' => 'De buffer (cache) is tijdelijk uitgeschakeld.',
	'info_chapeau' => 'Kop',
	'info_chapeau_2' => 'Kop :',
	'info_chemin_acces_1' => 'Opties: <b>Toegang tot het adresboek</b>',
	'info_chemin_acces_2' => 'Je dient de toegang tot de gegevens uit het adresboek in te stellen. Zonder deze instellingen is het ONmogelijk de gebruikersprofielen in dit adresboek te lezen.', # MODIF
	'info_chemin_acces_annuaire' => 'Opties: <b>Toegang in het adresboek',
	'info_choix_base' => 'Derde stap:',
	'info_classement_1' => '<sup>ste</sup> op @liste@',
	'info_classement_2' => '<sup>de</sup> @liste@',
	'info_code_acces' => 'Vergeet je eigen toegangscode niet!',
	'info_config_suivi' => 'Wanneer dit adres van een distributielijst is, kan je hieronder het adres opgeven waar deelnemers van de site zich kunnen inschrijven. Dit adres kan een URL zijn (het webadres voor het inschrijving op de lijst), of een emailadres met een onderwerp (zoals <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Je kan je op de mailinglijst van deze site inschrijven. Je zal dan via e-mail een aankondiging ontvangen van artikelen en nieuwsflitsen die voor publicatie werden voorgesteld.',
	'info_confirmer_passe' => 'Bevestig het nieuwe wachtwoord:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Let op: de volgende velden werden elders gewijzigd. Jouw wijzigingen op deze velden werden dus niet geregistreerd.',
	'info_conflit_edition_differences' => 'Verschillen :',
	'info_conflit_edition_version_enregistree' => 'De geregistreerde versie :',
	'info_conflit_edition_votre_version' => 'Jouw versie:',
	'info_connexion_base' => 'Proberen op de database aan te sluiten',
	'info_connexion_base_donnee' => 'Aansluiten op je database',
	'info_connexion_ldap_ok' => 'De LDAP-verbinding is gelukt. </b><p>Je kunt doorgaan naar de volgende stap.</p>',
	'info_connexion_mysql' => 'Je SQL verbinding',
	'info_connexion_ok' => 'De verbinding is geslaagd.',
	'info_contact' => 'Contact',
	'info_contenu_articles' => 'Inhoud van de artikelen',
	'info_contributions' => 'Bijdragen',
	'info_creation_paragraphe' => 'Om alinea’s te maken laat je gewoon enkele regels leeg.',
	'info_creation_rubrique' => 'Alvorens artikelen te kunnen schrijven<br /> moet minstens een rubriek worden gemaakt.<br />',
	'info_creation_tables' => 'Aanmaken van tabellen in de database',
	'info_creer_base' => '<b>Creëren</b> een nieuw database:',
	'info_dans_rubrique' => 'In de rubriek:',
	'info_date_publication_anterieure' => 'Datum van eerdere redactie:',
	'info_date_referencement' => 'DATUM VAN DE KOPPELING VAN DEZE SITE:',
	'info_derniere_etape' => 'Klaar!',
	'info_descriptif' => 'Beschrijving:',
	'info_desinstaller_plugin' => 'verwijdert de gegevens en deactiveert de plugin',
	'info_discussion_cours' => 'Lopende discussies',
	'info_ecrire_article' => 'Alvorens een artikel te kunnen schrijven, dien je minimaal één rubriek aan te maken.',
	'info_email_envoi' => 'Verzendadres (optioneel)',
	'info_email_envoi_txt' => 'Geef hieronder het adres op dat gebruikt wordt voor het versturen van e-mails. (Standaard wordt het adres van de geadresseerde als verzendadres gebruikt.):',
	'info_email_webmestre' => 'E-mailadres webmaster', # MODIF
	'info_envoi_email_automatique' => 'Automatisch verzenden van e-mails',
	'info_envoyer_maintenant' => 'Nu versturen',
	'info_etape_suivante' => 'Naar de volgende stap ',
	'info_etape_suivante_1' => 'Je kunt de volgende stap zetten.',
	'info_etape_suivante_2' => 'Je kunt de volgende stap zetten.',
	'info_exceptions_proxy' => 'Uitzonderingen op de proxy',
	'info_exportation_base' => 'Uitvoer van de database naar @archive@',
	'info_facilite_suivi_activite' => 'Om de opvolging en redactie van artikelen te vergemakkelijken, kan SPIP mails versturen -bijvoorbeeld naar een mailinglist van redacteurs- met de aankondiging van vragen voor publicatie of goedgekeurde publicaties.', # MODIF
	'info_fichiers_authent' => 'Verificatiebestand ".htpasswd"',
	'info_forums_abo_invites' => 'Je site bevat forums met abonnement; bezoekers worden dus op de publieke site verzocht zich in te schrijven.', # MODIF
	'info_gauche_admin_tech' => '<b>Deze pagina is enkel toegankelijk voor beheerders van de site.</b><p> Ze geeft toegang tot allerlei technische onderhoudstaken. Voor het uitvoeren van sommige taken zijn een afzonderlijke aanmelding en toegang tot je site via FTP nodig.</p>',
	'info_gauche_auteurs' => 'Je vindt hier alle auteurs van de site.
 Hun status is te herkennen aan de kleur van het icoontje (beheerder = groen; redacteur = geel).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Externe auteurs, zonder toegang tot de site, zijn aangeduid met een blauw icoontje,
gewiste auteurs met een grijze.',
	'info_gauche_messagerie' => 'Het berichtensysteem laat toe om berichten uit te wisselen tussen redacteurs, memo’s (voor persoonlijk gebruik) te bewaren of aankondigingen te tonen op de beginpagina van de privé-ruimte (als je beheerder bent).', # MODIF
	'info_gauche_statistiques_referers' => 'Deze pagina toont een lijst met <i>referers</i> (sites die een koppeling bevatten naar je eigen site), alleen voor vandaag en gisteren: de lijst wordt elke 24 uur opnieuw aangemaakt.',
	'info_gauche_visiteurs_enregistres' => 'Hier zal je de geregistreerde bezoekers van de
 publieke site vinden (forums met inschrijving).',
	'info_generation_miniatures_images' => 'Aanmaak van miniatuurafbeeldingen',
	'info_gerer_trad_objets' => '@objets@: het beheer van de vertalingskoppelingen',
	'info_hebergeur_desactiver_envoi_email' => 'Sommige hostingbedrijven staan het automatisch versturen van e-mails via hun servers niet toe. In dat geval zal de volgende functionaliteit van SPIP niet werken.',
	'info_hier' => 'gisteren:',
	'info_identification_publique' => 'Je publieke identiteit...',
	'info_image_process' => 'Kies de beste methode om een miniatuurafbeelding te maken door op de bijhorende afbeelding te klikken.',
	'info_image_process2' => 'Wanneer geen enkel beeld wordt getoond, betekent dit dat de server van je website niet is ingesteld om deze tools te gebruiken. Als je van deze functies gebruik wil maken, dien je de technische verantwoordelijke van de server te contacteren en te vragen naar «GD» of «Imagick» extensies.',
	'info_images_auto' => 'Beelden automatisch berekend',
	'info_informations_personnelles' => 'Persoonlijke gegevens',
	'info_inscription' => 'Ingeschreven op',
	'info_inscription_automatique' => 'Automatische inschrijving van nieuwe redacteurs', # MODIF
	'info_jeu_caractere' => 'Tekenset van de site',
	'info_jours' => 'dagen',
	'info_laisser_champs_vides' => 'velden leeglaten)',
	'info_langues' => 'Talen van de site',
	'info_ldap_ok' => 'De LDAP-autentificatie is geïnstalleerd',
	'info_lien_hypertexte' => 'Hypertekst koppeling:',
	'info_liste_nouveautes_envoyee' => 'Het lijst met nieuwe bijdragen werd verstuurd',
	'info_liste_redacteurs_connectes' => 'Lijst met online redacteuren', # MODIF
	'info_login_existant' => 'Deze login is reeds in gebruik',
	'info_login_trop_court' => 'Login te kort.',
	'info_login_trop_court_car_pluriel' => 'De login moet minstens @nb@ teken bevatten.',
	'info_logos' => 'De logo’s',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'In dezelfde rubriek',
	'info_message_en_redaction' => 'Je berichten in redactie',
	'info_message_technique' => 'Technisch bericht:',
	'info_messagerie_interne' => 'Intern berichtensysteem',
	'info_mise_a_niveau_base' => 'update van je SQL-database',
	'info_mise_a_niveau_base_2' => '{{LET OP!}} Je hebt een SPIP-versie geïnstalleerd die {ouder} is dan diegene die zich eerder op deze site bevond.: je database loopt hierdoor het risico beschadigd te worden waardoor je site niet meer zal functioneren.<br />{{Herinstalleer de SPIP-bestanden.}}',
	'info_modification_enregistree' => 'Je wijziging werd geregistreerd',
	'info_modifier_auteur' => 'De auteur wijzigen:',
	'info_modifier_rubrique' => 'De rubriek wijzigen:',
	'info_modifier_titre' => 'Wijzigen: @titre@',
	'info_mon_site_spip' => 'Mijn SPIP-site',
	'info_moyenne' => 'gemiddeld:',
	'info_multi_cet_article' => 'Gebruikte taal in dit artikel is:',
	'info_multi_langues_choisies' => 'Kies hierna welke talen ter beschikking staan van de redacteurs van je site.
  Talen die al worden gebruikt (vooraan in de lijst getoond) kunnen niet geschrapt worden.
', # MODIF
	'info_multi_objets' => '@objets@ : Activeer de taalmenu',
	'info_multi_secteurs' => '... enkel voor de hoofdrubrieken?',
	'info_nb_articles' => '@nb@ artikelen',
	'info_nb_auteurs' => '@nb@ auteurs',
	'info_nb_messages' => '@nb@ berichten',
	'info_nb_mots_cles' => '@nb@ trefwoorden',
	'info_nb_rubriques' => '@nb@ rubrieken',
	'info_nb_visiteurs' => '@nb@ bezoekers',
	'info_nom' => 'Naam',
	'info_nom_destinataire' => 'Naam van de geadresseerde',
	'info_nom_pas_conforme' => 'HTML bakens zijn niet toegestaan',
	'info_nom_site' => 'Naam van je site',
	'info_nombre_articles' => '@nb_articles@ artikelen,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubrieken, ',
	'info_nombre_sites' => '@nb_sites@ sites,',
	'info_non_deplacer' => 'Niet verplaatsen...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP kan regelmatig een bericht versturen om de laatste  nieuwtjes van de site te melden
   (recent gepubliceerde artikelen en nieuwsflitsen).',
	'info_non_envoi_liste_nouveautes' => 'De lijst met nieuwe bijdragen niet versturen',
	'info_non_modifiable' => 'kan niet gewijzigd worden',
	'info_non_suppression_mot_cle' => 'ik wil dit trefwoord niet verwijderen.',
	'info_notes' => 'Voetnoot',
	'info_nouvel_article' => 'Nieuw artikel',
	'info_nouvelle_traduction' => 'Nieuwe vertaling :',
	'info_numero_article' => 'ARTIKEL NUMMER:',
	'info_obligatoire_02' => '(verplicht)', # MODIF
	'info_option_accepter_visiteurs' => 'Inschrijving van bezoekers van de publieke site aanvaarden', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Inschrijving van bezoekers weigeren', # MODIF
	'info_options_avancees' => 'GEAVANCEERDE OPTIES',
	'info_ou' => 'of...',
	'info_page_interdite' => 'Verboden pagina',
	'info_par_nom' => 'op naam',
	'info_par_nombre_article' => 'volgens aantal artikelen',
	'info_par_statut' => 'op status',
	'info_par_tri' => '’(per @tri@)’',
	'info_passe_trop_court' => 'Te kort wachtwoord.',
	'info_passe_trop_court_car_pluriel' => 'Het wachtwoord moet ten minste @nb@ teken bevatten.',
	'info_passes_identiques' => 'Beide wachtwoorden zijn niet identiek.',
	'info_plus_cinq_car' => 'Meer dan 5 karakters',
	'info_plus_cinq_car_2' => '(Meer dan 5 karakters)',
	'info_plus_trois_car' => '(Meer dan 3 karakters)',
	'info_popularite' => 'populariteit: @popularite@; bezoeken: @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'voor',
	'info_preview_texte' => 'Nu is het ook mogelijk om de site in preview mode te zien, alsof alle artikelen en berichten (indien ze tenminste werden « voorgesteld voor publicatie ») ook echt waren gepubliceerd. Dient deze mogelijkheid uitsluitend te worden voorzien voor de beheerders, voor alle redacteurs of voor niemand?', # MODIF
	'info_procedez_par_etape' => 'vervolg stap voor stap',
	'info_procedure_maj_version' => 'de procedure voor de update die nodig is om de database aan te passen aan de nieuwe versie van SPIP.',
	'info_proxy_ok' => 'Test van proxy geslaagde.',
	'info_ps' => 'N.B.',
	'info_publier' => 'publiceren',
	'info_publies' => 'Je gepubliceerde artikelen',
	'info_question_accepter_visiteurs' => 'Als de sjablonen van je site voorzien dat bezoekers zich kunnen registreren zonder toegang tot de privé-ruimte, activeer dan de volgende optie :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Aanvaard je inschrijvingen van nieuwe redacteuren vanaf
 de publieke site? Indien wel, dan kunnen bezoekers
 zich via een geautomatiseerd formulier inschrijven en
 toegang krijgen tot de privé-ruimte om zelf artikelen
 voor te stellen. <div class="notice">Bij inschrijving zal een
 gebruiker een automatische e-mail ontvangen met daarin
 de toeganscode voor de site. Sommige hostingproviders
 blokkeren echter het versturen van e-mail vanaf hun
 servers: in dat geval is een automatische inschrijving
 niet mogelijk.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ heeft @date_diff@ minuten geleden aan deze inhoud gewerkt ',
	'info_racine_site' => 'Begin van de site',
	'info_recharger_page' => 'Laad deze pagina over enkele ogenblikken opnieuw.',
	'info_recherche_auteur_zero' => 'Geen resultaat voor « @cherche_auteur@ ».',
	'info_recommencer' => 'Probeer nogmaals, alstublieft.',
	'info_redacteur_1' => 'Redacteur',
	'info_redacteur_2' => 'met toegang tot de privé-ruimte (<i>aanbevolen</i>)',
	'info_redacteurs' => 'Redacteurs',
	'info_redaction_en_cours' => 'IN REDACTIE',
	'info_redirection' => 'Doorverwijzing',
	'info_redirection_activee' => 'De doorverwijzing is ingeschakeld.',
	'info_redirection_boucle' => 'Je probeert het artikel naar zichzelf door te verwijzen.',
	'info_redirection_desactivee' => 'De doorverwijzing is verwijderd.',
	'info_refuses' => 'Je geweigerde artikelen',
	'info_reglage_ldap' => 'Opties: <b>Instellen van de LDAP invoer</b>',
	'info_renvoi_article' => '<b>Doorverwijzing.</b> Dit artikel verwijst naar de pagina:',
	'info_reserve_admin' => 'Alleen beheerders kunnen dit adres wijzigen.', # MODIF
	'info_restreindre_rubrique' => 'Beheer tot deze rubriek beperken:',
	'info_resultat_recherche' => 'Resultaat van de zoekopdracht:',
	'info_rubriques' => 'Rubrieken',
	'info_rubriques_02' => 'rubrieken',
	'info_rubriques_trouvees' => 'Gevonden rubrieken',
	'info_sans_titre' => 'Zonder titel',
	'info_selection_chemin_acces' => '<b>Selecteer</b> hierna de toegangswijze tot het adresboek:',
	'info_signatures' => 'namen',
	'info_site' => 'Site',
	'info_site_2' => 'site:',
	'info_site_min' => 'site',
	'info_site_reference_2' => 'Gekoppelde website',
	'info_site_web' => 'Website:',
	'info_sites' => 'sites',
	'info_sites_lies_mot' => 'Referentiesites gekoppeld aan het trefwoord ',
	'info_sites_proxy' => 'Een proxy gebruiken',
	'info_sites_trouves' => 'Gevonden websites ',
	'info_sous_titre' => 'Ondertitel:',
	'info_statut' => 'Status',
	'info_statut_administrateur' => 'Beheerder', # MODIF
	'info_statut_auteur' => 'Status van deze auteur:',
	'info_statut_auteur_2' => 'Ik ben',
	'info_statut_auteur_a_confirmer' => 'Te bevestigen inschrijving',
	'info_statut_auteur_autre' => 'Andere status:',
	'info_statut_redacteur' => 'Redacteur',
	'info_statut_utilisateurs_1' => 'Standaardstatus voor de ingevoerde gebruikers', # MODIF
	'info_statut_utilisateurs_2' => 'Kies de status die de personen uit het LDAP-adressenboek toebediend krijgen als ze de eerste keer inloggen. Nadien kan je de status van een individuele auteur wijzigen.', # MODIF
	'info_suivi_activite' => 'Opvolgen van de editoriale activiteit',
	'info_surtitre' => 'Opschrift:',
	'info_syndication_integrale_1' => 'Je site stelt syndicatiebestanden voor (zie « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Wil je integrale artikelen doorgeven of enkel een samenvatting van enkele honderden karakters doorgeven ?',
	'info_table_prefix' => 'Je kunt het voorvoegsel van de naam van de databasetabel aanpassen (dit is absoluut noodzakelijk wanneer er verschillende sites in dezelfde database zitten). Dit voorvoegsel schrijf je in kleine letters, zonder accenten of spaties.',
	'info_taille_maximale_images' => 'SPIP zal de maximumomvang van de beelden testen die hij kan behandelen (in miljoenen pixels). <br/> zullen de grotere beelden niet verminderd zijn.',
	'info_taille_maximale_vignette' => 'Maximale grootte van de mini-afbeeldingen gemaakt door het systeem:',
	'info_terminer_installation' => 'Je kan de standaardinstallatieprocedure nu beëindigen.',
	'info_texte' => 'Tekst',
	'info_texte_explicatif' => 'Uitleg',
	'info_texte_long' => '(de tekst is lang: hij zal bijgevolg in verschillende delen verschijnen die opnieuw bij elkaar worden gevoegd na goedkeuring van de tekst.)',
	'info_texte_message' => 'Tekst van je bericht',
	'info_texte_message_02' => 'Tekst van het bericht',
	'info_titre' => 'Titel:',
	'info_total' => 'totaal:',
	'info_tous_articles_en_redaction' => 'Alle artikelen in redactie',
	'info_tous_articles_presents' => 'Alle in deze rubriek gepubliceerde artikelen',
	'info_tous_articles_refuses' => 'Alle afgewezen artikelen',
	'info_tous_les' => 'alle:',
	'info_tout_site' => 'Volledige site',
	'info_tout_site2' => 'Het artikel werd niet in deze taal vertaald.',
	'info_tout_site3' => 'Het artikel werd in deze taal vertaald maar aan het bronartikel werden wijzigingen aangebracht. De vertaling dient geactualiseerd te worden.',
	'info_tout_site4' => 'Het artikel is vertaald naar deze taal en de vertaling is geactualiseerd.',
	'info_tout_site5' => 'Origineel artikel.',
	'info_tout_site6' => '<b>LET OP:</b> alleen de originele artikelen worden getoond.
Vertalingen worden gelinkt aan het origineel,
een kleur geeft hun status aan:',
	'info_traductions' => 'Vertalingen',
	'info_travail_colaboratif' => 'Samenwerking op artikelen',
	'info_un_article' => 'een artikel, ',
	'info_un_site' => 'een website, ',
	'info_une_rubrique' => 'een rubriek, ',
	'info_une_rubrique_02' => '1 rubriek',
	'info_url' => 'URL:',
	'info_url_proxy' => 'Proxy-URL',
	'info_url_proxy_pas_conforme' => 'De URL van de proxy is ongeldig.',
	'info_url_site_pas_conforme' => 'De site URL is niet geldig.',
	'info_url_test_proxy' => 'Test-URL',
	'info_urlref' => 'Adres van de koppeling:',
	'info_utilisation_spip' => 'Je kan het publicatiesysteem nu gebruiken...',
	'info_visites_par_mois' => 'Weergave per maand:',
	'info_visiteur_1' => 'Bezoeker',
	'info_visiteur_2' => 'van de publieke site',
	'info_visiteurs' => 'Bezoekers',
	'info_visiteurs_02' => 'Bezoekers van de publieke site',
	'info_webmestre_forces' => 'Webmasters zijn op dit moment gedefinieerd in <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Adres van de database die door de provider wordt toegekend',
	'install_connect_ok' => 'De nieuwe database is gedeclareerd als server @connect@.',
	'install_echec_annonce' => 'De installatie zal wellicht mislukken of leiden tot een niet-werkende site...',
	'install_extension_mbstring' => 'SPIP functioneert niet met:',
	'install_extension_php_obligatoire' => 'SPIP benodigt de PHP-extensie:',
	'install_login_base_hebergeur' => 'Login van aansluiten die door de provider wordt toegekend',
	'install_nom_base_hebergeur' => 'De naam van de database die door de provider wordt toegekend:',
	'install_pas_table' => 'Database momenteel zonder tabellen',
	'install_pass_base_hebergeur' => 'Wachtwoord van aansluiten dat door de provider wordt toegekend',
	'install_php_version' => 'PHP versie @version@ onvoldoende (minimum = @minimum@)',
	'install_select_langue' => 'Kies een taal en klik vervolgens op de knop  «volgende» om de installatie te beginnen.',
	'install_select_type_db' => 'Het type database aangeven:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Databaseserver die door de provider wordt toegekend',
	'install_table_prefix_hebergeur' => 'Het voorvoegsel van de tabel dat door de provider wordt toegekend:',
	'install_tables_base' => 'Tabellen van de database',
	'install_types_db_connus' => 'SPIP kan <b>MySQL</b> (het meest verbreid), <b>PostgreSQL</b> en <b>SQLite</b> gebruiken.',
	'install_types_db_connus_avertissement' => '<b>PostgreSQL</b>support wordt experimenteel voorgesteld.',
	'instituer_erreur_statut_a_change' => 'De status werd al gewijzigd',
	'instituer_erreur_statut_non_autorise' => 'Je kunt niet kiezen voor deze status',
	'intem_redacteur' => 'redacteur',
	'intitule_licence' => 'Licentie',
	'item_accepter_inscriptions' => 'Inschrijvingen aanvaarden',
	'item_activer_messages_avertissement' => 'Waarschuwingsberichten activeren',
	'item_administrateur_2' => 'beheerder', # MODIF
	'item_afficher_calendrier' => 'Op de kalender tonen',
	'item_autoriser_syndication_integrale' => 'Volledige artikelen verspreiden via syndicatiebestanden',
	'item_choix_administrateurs' => 'de beheerders', # MODIF
	'item_choix_generation_miniature' => 'Automatisch aanmaken van verkleinde afbeeldingen.',
	'item_choix_non_generation_miniature' => 'Geen verkleinde afbeeldingen aanmaken.',
	'item_choix_redacteurs' => 'de redacteurs',
	'item_choix_visiteurs' => 'bezoekers van de publieke site',
	'item_creer_fichiers_authent' => 'de .htpasswd bestanden aanmaken',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'De berichtendienst en de agenda activeren',
	'item_mots_cles_association_articles' => 'aan artikelen',
	'item_mots_cles_association_rubriques' => 'aan rubrieken',
	'item_mots_cles_association_sites' => 'aan gesyndiceerde of gerefereerde sites.',
	'item_non' => 'Nee',
	'item_non_accepter_inscriptions' => 'Geen inschrijvingen aanvaarden',
	'item_non_activer_messages_avertissement' => 'Geen waarschuwingsberichten',
	'item_non_afficher_calendrier' => 'Niet tonen op de kalender',
	'item_non_autoriser_syndication_integrale' => 'Alleen een samenvatting verspreiden',
	'item_non_creer_fichiers_authent' => 'Deze bestanden niet aanmaken',
	'item_non_messagerie_agenda' => 'De berichtendienst en de agenda deactiveren',
	'item_non_publier_articles' => 'Artikelen niet vrijgeven voor de vastgelegde datum van publicatie',
	'item_nouvel_auteur' => 'Nieuwe auteur',
	'item_nouvelle_rubrique' => 'Nieuwe rubriek',
	'item_oui' => 'Ja',
	'item_publier_articles' => 'Artikelen publiceren, ongeacht hun publicatiedatum.',
	'item_reponse_article' => 'Antwoord op artikel',
	'item_visiteur' => 'bezoeker',

	// J
	'jour_non_connu_nc' => 'onbekend',

	// L
	'label_bando_outils' => 'Knoppenbalk',
	'label_bando_outils_afficher' => 'Knoppenbalk tonen',
	'label_bando_outils_masquer' => 'Knoppenbalk verbergen',
	'label_choix_langue' => 'Selecteer je taal',
	'label_nom_fichier_connect' => 'Geef de naam die wordt gebruikt voor deze server',
	'label_slogan_site' => 'Slogan',
	'label_taille_ecran' => 'Breedte van het scherm',
	'label_texte_et_icones_navigation' => 'Navigatiemenu',
	'label_texte_et_icones_page' => 'Weergave op de pagina',
	'ldap_correspondance' => 'erfenis van het veld @champ@',
	'ldap_correspondance_1' => 'Erfenis van de LDAP velden',
	'ldap_correspondance_2' => 'Voor elk volgend SPIP veld, de naam van het overeenkomstige LDAP veld aangeven. Leeglaten om niets in te vullen, door spaties of komma’s gescheiden om verschillende LDAP velden te proberen.',
	'lien_ajouter_auteur' => 'Voeg deze auteur toe',
	'lien_ajouter_une_rubrique' => 'Deze rubriek toevoegen',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NAAM WEBSITE:',
	'lien_rapide_contenu' => 'Naar de inhoud gaan',
	'lien_rapide_navigation' => 'Naar de navigatie gaan',
	'lien_rapide_recherche' => 'Op zoek gaan',
	'lien_retirer_auteur' => 'Auteur verwijderen',
	'lien_retirer_rubrique' => 'Rubriek verwijderen',
	'lien_retirer_tous_auteurs' => 'Verwijder alle auteurs',
	'lien_retirer_toutes_rubriques' => 'Alle rubrieken verwijderen',
	'lien_site' => 'site',
	'lien_tout_decocher' => 'Alles deselecteren',
	'lien_tout_deplier' => 'Alles uitvouwen',
	'lien_tout_replier' => 'Alles opvouwen',
	'lien_tout_supprimer' => 'Alles verwijderen',
	'lien_trier_nom' => 'Sorteer op naam',
	'lien_trier_nombre_articles' => 'Sorteer op aantal artikelen',
	'lien_trier_statut' => 'Sorteer op status',
	'lien_voir_en_ligne' => 'ONLINE BEKIJKEN:',
	'logo_article' => 'Logo van het artikel',
	'logo_auteur' => 'Logo van de auteur',
	'logo_rubrique' => 'Logo van de rubriek ',
	'logo_site' => 'Logo van deze site',
	'logo_standard_rubrique' => 'Standaard logo rubrieken',
	'logo_survol' => 'Logo voor rollover',

	// M
	'menu_aide_installation_choix_base' => 'Database kiezen',
	'module_fichier_langue' => 'Taalbestand',
	'module_raccourci' => 'Snelkoppeling',
	'module_texte_affiche' => 'Weergegeven tekst',
	'module_texte_explicatif' => 'Je kan de volgende snelkoppelingen invoegen in de skeletten van je publieke site. Ze worden automatisch vertaald in de verschillende talen waarvoor een taalbestand is aangemaakt.',
	'module_texte_traduction' => 'Het taalbestand « @module@ » is beschikbaar in het:',
	'mois_non_connu' => 'Onbekend',

	// N
	'nouvelle_version_spip' => 'Versie @version@ van SPIP is beschikbaar',
	'nouvelle_version_spip_majeure' => 'Een nieuwe versie van SPIP @version@ is beschikbaar',

	// O
	'onglet_contenu' => 'Inhoud',
	'onglet_declarer_une_autre_base' => 'Een andere database declareren',
	'onglet_discuter' => 'Discussiëren',
	'onglet_interactivite' => 'Interactiviteit',
	'onglet_proprietes' => 'Eigendommen',
	'onglet_repartition_actuelle' => 'nu',
	'onglet_sous_rubriques' => 'Subrubrieken',

	// P
	'page_pas_proxy' => 'Deze bladzijde moet niet via proxy gaan',
	'pas_de_proxy_pour' => 'Geef desnoods de machines of gebieden aan waarvoor deze proxy niet van toepassing moet zijn (bijvoorbeeld: @exemple@)',
	'phpinfo' => 'PHP Configuratie',
	'plugin_charge_paquet' => 'Inladen van het pakket @name@',
	'plugin_charger' => 'Download',
	'plugin_erreur_charger' => 'fout: onmogelijk om @zip@ te laden',
	'plugin_erreur_droit1' => 'Er kan niet worden geschreven naar <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Controleer de rechten op deze map (en maak hem eventueel aan), of plaats de bestanden via FTP.',
	'plugin_erreur_zip' => 'pclzip fout: fout @status@',
	'plugin_etat_developpement' => 'in ontwikkeling',
	'plugin_etat_experimental' => 'experimenteel',
	'plugin_etat_stable' => 'stabiel',
	'plugin_etat_test' => 'in test',
	'plugin_impossible_activer' => 'Onmogelijk om plugin @plugin@ te activeren',
	'plugin_info_automatique1' => 'Als je de automatische installatie van plugins wilt toelaten, moet je:',
	'plugin_info_automatique1_lib' => 'Als je de automatische installatie van deze bibliotheek toe wilt laten:',
	'plugin_info_automatique2' => 'een lijst <code>@rep@</code> aanmaken;',
	'plugin_info_automatique3' => 'controleren dat de server het recht heeft om in deze map te schrijven.',
	'plugin_info_automatique_creer' => 'om in de siteroot te creëren.',
	'plugin_info_automatique_exemples' => 'voorbeelden:',
	'plugin_info_automatique_ftp' => 'Je kunt een plugin met FTP in de map <tt>@rep@</tt> plaatsen',
	'plugin_info_automatique_lib' => 'Sommige plugins vragen eveneens om bestanden in map <code>lib/</code> te kunnen downloaden, die in de root van de site moet bestaan.',
	'plugin_info_automatique_liste' => 'Je lijst van plugins:',
	'plugin_info_automatique_liste_officielle' => 'officiële plugins',
	'plugin_info_automatique_liste_update' => 'De lijsten bijwerken',
	'plugin_info_automatique_ou' => 'om...',
	'plugin_info_automatique_select' => 'Selecteert hieronder een plugin: SPIP zal hem downloaden en in map <code>@rep@</code> plaatsen; als de plugin al bestaat, zal hij worden bijgewerkt.',
	'plugin_info_credit' => 'Credits',
	'plugin_info_erreur_xml' => 'De declaratie van deze plugin is onjuist',
	'plugin_info_install_ok' => 'Succesvolle installatie',
	'plugin_info_necessite' => 'Benodigd:',
	'plugin_info_non_compatible_spip' => 'Deze plugin is niet compatibel met deze versie van SPIP',
	'plugin_info_plugins_dist_1' => 'De onderstaande plugins zijn geladen en geactiveerd in de directory @plugins_dist@.', # extensies zijn speciaale plugins geleeverd met spip-core om een gebruikbare SPIP pakket te bouwen
	'plugin_info_plugins_dist_2' => 'Ze zijn niet te deactiveren.',
	'plugin_info_telecharger' => 'om vanaf @url@ te downloaden en te plaatsen in @rep@',
	'plugin_info_upgrade_ok' => ' Update geslaagd',
	'plugin_librairies_installees' => 'Geïnstalleerde bibliotheken',
	'plugin_necessite_extension_php' => 'De PHP-extensie @plugin@ is benodigd in versie @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Benodigde PHP-extensie: @plugin@',
	'plugin_necessite_lib' => 'Deze plugin vereist de library @lib@',
	'plugin_necessite_php' => 'Vereist @plugin@ in versie @version@.',
	'plugin_necessite_plugin' => 'Vereist plugin @plugin@ met minimale versie @version@.',
	'plugin_necessite_plugin_sans_version' => 'Vereist plugin @plugin@ ',
	'plugin_necessite_spip' => 'Vereist SPIP in minimale versie @version@.',
	'plugin_source' => 'bron: ',
	'plugin_titre_automatique' => 'Automatische installatie',
	'plugin_titre_automatique_ajouter' => 'Een plugin toevoegen',
	'plugin_titre_installation' => 'Het installeren van plugin @plugin@',
	'plugin_titre_modifier' => 'Mijn plugins',
	'plugin_utilise_extension_php' => 'Gebruik de PHP-extensie @plugin@ in versie @version@.', # MODIF
	'plugin_utilise_php' => 'Gebruikt @plugin@ in versie @version@.', # MODIF
	'plugin_utilise_plugin' => 'Gebruikt plugin @plugin@ met versie @version@.', # MODIF
	'plugin_zip_active' => 'Gaat door om het te activeren',
	'plugin_zip_adresse' => 'geef hieronder het adres van een zipbestand om de plugin te downloaden, of het adres van een lijst van plugins.',
	'plugin_zip_adresse_champ' => 'Adres van plugin of van de lijst ',
	'plugin_zip_content' => 'Hij bevat de volgende bestanden (@taille@), <br/>klaar om in de map <code>@rep@</code> te worden geplaatst',
	'plugin_zip_installe_finie' => 'Het bestand @zip@ is geunzipt en werd geplaatst.',
	'plugin_zip_installe_rep_finie' => 'Het bestand @zip@ is geunzipt en werd in de map @rep@ geplaatst',
	'plugin_zip_installer' => 'Je kunt hem nu installeren.',
	'plugin_zip_telecharge' => 'Het bestand @zip@ werd geladen',
	'plugins_actif_aucun' => 'Geen plugins ingeschakeld.',
	'plugins_actif_un' => 'Eén plugin is ingeschakeld.',
	'plugins_actifs' => '@count@ plugins activeren.',
	'plugins_actifs_liste' => 'Actief',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Eén plugin beschikbaar.',
	'plugins_disponibles' => '@count@ plugins beschikbaar.',
	'plugins_erreur' => 'De fout in plugins: @plugins@',
	'plugins_liste' => 'Lijst van plugins',
	'plugins_liste_dist' => 'Vergrendelde plugins', # "locked" in english
	'plugins_recents' => 'Recente plugins.',
	'plugins_tous_liste' => 'Alle',
	'plugins_vue_hierarchie' => 'Hiërarchie',
	'plugins_vue_liste' => 'Lijst',
	'protocole_ldap' => 'De versie van het protocol:',

	// Q
	'queue_executer_maintenant' => 'Nu uitvoeren',
	'queue_info_purger' => 'Je kunt alle wachtende taken verwijderen en de lijst van periodieke taken herstarten', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ wachtrij', # MODIF
	'queue_next_job_in_nb_sec' => 'Volgende opdracht in @nb@ sec', # MODIF
	'queue_no_job_in_queue' => 'Geen opdracht in de wachtrij', # MODIF
	'queue_one_job_in_queue' => '1 taak in wachtrij', # MODIF
	'queue_priorite_tache' => 'prioriteit',
	'queue_purger_queue' => 'De takenlijst leegmaken', # MODIF
	'queue_titre' => 'Lijst van taken', # MODIF

	// R
	'repertoire_plugins' => 'Map:',
	'required' => '(verplicht)', # MODIF

	// S
	'sans_heure' => 'zonder tijdstip',
	'statut_admin_restreint' => 'beperkte beheerder',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'CRON taak @function@ (ASAP)',
	'tache_cron_secondes' => 'CRON taak @function@ (om de @nb@ sec)',
	'taille_cache_image' => 'De door SPIP automatisch aangemaakte afbeeldingen (icoontjes van documenten, grafisch weergegeven titels, wiskundige functies in TeX formaat...) nemen in map @dir@ in totaal @taille@ in.',
	'taille_cache_moins_de' => 'De cache is kleiner dan @octets@.',
	'taille_cache_octets' => 'De grootte van de buffer bedraagt momenteel @octets@.',
	'taille_cache_vide' => 'De buffer is leeg.',
	'taille_repertoire_cache' => 'Grootte van het bufferbestand',
	'text_article_propose_publication' => 'Artikel voorgesteld voor publicatie.',
	'texte_acces_ldap_anonyme_1' => 'Sommige LDAP-servers aanvaarden geen anonieme toegang. In zo’n geval dien je één loginnaam op te geven om vervolgens informatie in het adressenboek te zoeken. In de meeste gevallen kan je de volgende velden echter leeg laten.',
	'texte_admin_effacer_01' => 'Met dit commando vernietig je de <i>volledige</i> inhoud van de database,
inbegrepen <i>alle</i> toegangsrechten voor redacteurs en beheerders. Nadat je dit uitgevoerd hebt, dien je de herinstallatie van SPIP te starten om een volledig nieuwe database aan te maken met toegangsrechten voor een eerste beheerder.', # MODIF
	'texte_adresse_annuaire_1' => '(Als de map geïnstalleerd is op dezelfde computer als je website, is het waarschijnlijk «localhost».)',
	'texte_ajout_auteur' => 'Deze auteur werd aan het artikel toegevoegd:',
	'texte_annuaire_ldap_1' => 'Als je toegang hebt tot een LDAP-adresboek, kan je dit gebruiken om automatisch gebruikers in te voeren in SPIP.', # MODIF
	'texte_article_statut' => 'Dit artikel is:',
	'texte_article_virtuel' => 'Virtueel artikel',
	'texte_article_virtuel_reference' => '<b>Virtueel artikel:</b> gekoppeld artikel in je SPIP site maar doorgestuurd naar een andere URL. Verwijder de URL om de doorverwijzing te stoppen.',
	'texte_aucun_resultat_auteur' => 'Geen resultaat voor "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Deze website kan een lijst met auteurs die op dat moment aangelogd zijn, tonen. Het is mogelijk om direkt berichten opsturen en ontvangen tussen de auteurs.  Je kan kiezen om niet in deze lijst te verschijnen (je wordt dan « onzichtbaar » voor de andere gebruikers).', # MODIF
	'texte_auteurs' => 'DE AUTEURS',
	'texte_choix_base_1' => 'Kies je database:',
	'texte_choix_base_2' => 'De SQL server bevat meerdere databases.',
	'texte_choix_base_3' => '<b>Kies</b> hierna die welke door jouw provider werd toegekend:',
	'texte_choix_table_prefix' => 'Voorvoegsel van de tabellen:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elementen',
	'texte_conflit_edition_correction' => 'Controleer hieronder de verschillen tussen beide versies van de tekst; je kunt eveneens jouw wijzigingen kopiëren en opnieuw beginnen.',
	'texte_connexion_mysql' => 'Raadpleegt de inlichtingen die door jouw provider worden verstrekt: je moet er de databaseserver vinden die men voorstelt en jouw persoonlijke identificaties om je erop aan te melden.',
	'texte_contenu_article' => '(Inhoud van het artikel in enkele woorden.)',
	'texte_contenu_articles' => 'Naargelang de opmaak van je website kan je beslissen sommige elementen van een artikel
 wel of niet te gebruiken.
 Geef op de lijst hieronder aan welke elementen je wil gebruiken.',
	'texte_crash_base' => 'Als je database gecrashed is,
  kan je een automatisch herstel proberen.',
	'texte_creer_rubrique' => 'Alvorens artikelen te kunnen schrijven, <br/> moet je een rubriek aanmaken.',
	'texte_date_creation_article' => 'DATUM VAN AANMAKEN VAN HET ARTIKEL:',
	'texte_date_creation_objet' => 'Aanmaakdatum:', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'Datum van eerdere redactie:',
	'texte_date_publication_anterieure_nonaffichee' => 'Verberg de datum van eerdere redactie.',
	'texte_date_publication_article' => 'DATUM VAN ONLINE PUBLICATIE:',
	'texte_date_publication_objet' => 'Datum van online publicatie:',
	'texte_definir_comme_traduction_rubrique' => 'Deze rubriek is een vertaling van rubrieknummer:',
	'texte_descriptif_rapide' => 'Korte beschrijving.',
	'texte_effacer_base' => 'Verwijder de SPIP database',
	'texte_effacer_statistiques' => 'De statistieken wissen',
	'texte_en_cours_validation' => 'De onderstaande inhoud wacht op goedkeuring.',
	'texte_enrichir_mise_a_jour' => 'De opmaak van een tekst kan gebeuren met behulp van zogeheten «typografische snelkoppelingen».',
	'texte_fichier_authent' => 'SPIP moet er dan speciale bestanden <tt>.htpasswd</tt>
  en <tt>.htpasswd-admin</tt> in de directory @dossier@ ?</b><p>
 Deze bestanden die je kunt gebruiken om toegang te beperken tot 
 auteurs en beheerders in andere delen van je site 
   (externe programma statistieken, bijvoorbeeld).</p><p>
Als dit geen geen nut heeft, kunt je de standaard instellingen behouden (geen nieuw bestand maken).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Nu zal het systeem een persoonlijke toegang tot de site voor je creëren.',
	'texte_informations_personnelles_2' => '(Nota: als het een herinstallatie betreft en je toegangscode blijkt nog steeds te werken, kan je',
	'texte_introductif_article' => '(Inleidende tekst op het artikel.)',
	'texte_jeu_caractere' => 'Het is aan te raden op je site het universele alfabet (<tt>utf-8</tt>) te gebruiken: dit laat de weergave van teksten toe in alle talen en stelt geen compatibilieitsprobleem met de recente browsers.',
	'texte_jeu_caractere_3' => 'Je site is momenteel geïnstalleerd in deze tekenset:',
	'texte_jeu_caractere_4' => 'Indien dit niet overeenkomt met je werkelijke gegevens (bvb bij het terugzetten van je database), of als je <em>deze site opstart</em> en met een andere tekenset van start wil gaan, geef dat dan hieronder aan:',
	'texte_login_ldap_1' => '(Leeg laten voor een anonieme login, of een volledig pad invullen, bijvoorbeeld «<tt>uid=janssen, ou=users, dc=mijn-domein, dc=com</tt>».)',
	'texte_login_precaution' => 'LET OP! Met deze login ben je momenteel aangemeld.
 Gebruik dit formulier met de nodige voorzichtigheid...',
	'texte_messagerie_agenda' => 'Een berichtendienst maakt het de redacteuren van de site mogelijk om in de privé ruimte berichten uit te wisselen. De dienst is gekoppeld aan een agenda.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Je hebt zonet de SPIP bestanden vernieuwd. Nu dien je
 eveneens de database te updaten.',
	'texte_modifier_article' => 'Wijzigen artikel:',
	'texte_multilinguisme' => 'Als je graag objecten in verschillende talen zou willen beheren, met een complexe navigatie, kan je een taalkeuzemenu toevoegen bij deze objecten, i.f.v de organisatie van je site.',
	'texte_multilinguisme_trad' => 'Je kan eveneens een systeem in werking stellen voor het beheer van koppelingen tussen de verschillende vertalingen van de objecten.',
	'texte_non_compresse' => '<i>niet gecomprimeerd</i> (de server ondersteunt deze functionaliteit niet)',
	'texte_nouvelle_version_spip_1' => 'Je hebt een nieuwe versie van SPIP geïnstalleerd.',
	'texte_nouvelle_version_spip_2' => 'Deze nieuwe SPIP-versie vereist een  grondiger update dan gewoonlijk. Als je webmaster bent van deze site, verwijder dan het bestand @connect@ en hervat de installatie om de verbindingsgegevens met de database te vernieuwen.<p> (NB: als je de verbindingsgegevens niet meer kent, kan je best eerst een blik werpen op het bestand @connect@ alvorens het te verwijderen...)</p>', # Pas de modif trouvée, la trad reste valable.
	'texte_operation_echec' => 'Ga terug naar de vorige pagina, selecteer een andere database of maak een nieuwe aan. Kijk nog eens alle gegevens na die je van je provider hebt ontvangen.',
	'texte_plus_trois_car' => 'meer dan 3 karakters',
	'texte_plusieurs_articles' => 'Meerdere auteurs gevonden voor "@cherche_auteur@":',
	'texte_port_annuaire' => '(De opgegeven standaardwaarde is meestal de juiste.)',
	'texte_presente_plugin' => 'Deze pagina toont de lijst van beschikbare plugins op deze site. Je kan de nodige plugins activeren door het overeenkomstige vakje aan te kruisen.',
	'texte_proposer_publication' => 'Wanneer je artikel gereed is, <br />kun je de publicatie ervan voorstellen.',
	'texte_proxy' => 'In bepaalde gevallen (intranet, beschermde netwerken), zijn de verwijderde plaatsen (SPIP documentatie , georganiseerde plaatsen, enz.) toegankelijk slechts door een <i>proxy HTTP</i>. Eventueel geeft hieronder zijn adres aan, onder de vorm @proxy_in_actie@. Over het algemeen zul je dit hokje leeg laten.',
	'texte_publication_articles_post_dates' => 'Hoe dient SPIP zich op te stellen ten opzichte van artikelen waarvan de
  publicatiedatum is vastgelegd op een
  toekomstige datum?',
	'texte_rappel_selection_champs' => '[Vergeet niet de juiste keuze te maken voor dit veld.]',
	'texte_recalcul_page' => 'Als je slechts één pagina wilt vernieuwen, doe je dit op de publieke site met de knop  «vernieuwen».',
	'texte_recuperer_base' => 'De database herstellen',
	'texte_reference_mais_redirige' => 'Gekoppeld artikel in je SPIP site, maar doorgestuurd naar een andere URL.',
	'texte_requetes_echouent' => '<b>Wanneer bepaalde SQL-query’s systematisch crashen zonder duidelijke reden, is dit mogelijk te wijten aan de database zelf.</b><p> Je SQL Server heeft een herstelmogelijkheid van tabellen die beschadigd zijn door een crash. Hier kunt je proberen dit te repareren. Wanneer dat niet lukt, bewaar dan een kopie van het scherm dat aanwijzingen over de problemen bevat...</p><p>Als het probleem zich blijft voordoen, contact opnemen met je provider.</p>',
	'texte_selection_langue_principale' => 'Hieronder kan je de «basistaal» van de site kiezen. Deze keuze verplicht je - gelukkig! - niet om artikelen in deze taal te schrijven, maar laat wel toe om het volgende te bepalen:
 <ul><li> het standaardformaat van de data op de publieke site;</li>
 <li> de aard van de typografische motor die SPIP dient te gebruiken om teksten te tonen;</li>
 <li> de taal die gebruikt moet worden op de formulieren van de publieke site;</li>
 <li> de taal die standaard wordt voorgesteld in het privé-gedeelte.</li></ul>',
	'texte_sous_titre' => 'Ondertitel',
	'texte_statistiques_visites' => '(donkere balkjes:  zondag / donkere lijn: evolutie van het gemiddelde)',
	'texte_statut_attente_validation' => 'wachten op goedkeuring',
	'texte_statut_publies' => 'online geplaatst',
	'texte_statut_refuses' => 'geweigerd',
	'texte_suppression_fichiers' => 'Gebruik dit commando om alle bestanden uit de  buffer (cache) te verwijderen.
Dit kan handig zijn als je veel pagina’s hebt gewijzigd, de layout of de structuur van de site hebt veranderd.
 De nieuwste pagina’s worden dan getoond en de buffer wordt opnieuw opgebouwd.',
	'texte_sur_titre' => 'Opschrift',
	'texte_table_ok' => ': deze tabel is OK.',
	'texte_tentative_recuperation' => 'Poging tot herstel.',
	'texte_tenter_reparation' => 'Poging tot herstel van de database',
	'texte_test_proxy' => 'Om de proxy te testen kan je hier het adres geven van de website die je wil bereiken.',
	'texte_titre_02' => 'Titel:',
	'texte_titre_obligatoire' => '<b>Titel</b> [verplicht]',
	'texte_travail_article' => '@nom_auteur_modif@ heeft @date_diff@ minuten geleden aan dit artikel gewerkt',
	'texte_travail_collaboratif' => 'Als het vaak gebeurt dat meerdere redacteurs aanhetzelfde artikel werken, kan het systeem tonen welke artikelen er recent «geopend» werden
 om te vermijden dat simultaan
 wijzigingen worden aangebracht.
 Deze optie is niet standaard geactiveerd om te vermijden dat er teveel waarschuwingsberichten op het
 scherm verschijnen.', # MODIF
	'texte_vide' => 'leeg',
	'texte_vider_cache' => 'Cache leegmaken',
	'titre_admin_tech' => 'Technisch onderhoud',
	'titre_ajouter_un_auteur' => 'Voeg een auteur toe',
	'titre_ajouter_un_mot' => 'Voeg een trefwoord toe',
	'titre_cadre_afficher_article' => 'Artikelen tonen',
	'titre_cadre_afficher_traductions' => 'Toon de status van de vertalingen voor de volgende talen:',
	'titre_cadre_ajouter_auteur' => 'EEN AUTEUR TOEVOEGEN:',
	'titre_cadre_interieur_rubrique' => 'Binnen rubriek',
	'titre_cadre_numero_auteur' => 'AUTEUR NUMMER',
	'titre_cadre_numero_objet' => '@objet@ NUMMER:',
	'titre_cadre_signature_obligatoire' => '<b>Handtekening</b> [Verplicht]<br />',
	'titre_config_contenu_notifications' => 'Kennisgevingen',
	'titre_config_contenu_prive' => 'In het privé gedeelte',
	'titre_config_contenu_public' => 'Op de openbare site',
	'titre_config_fonctions' => 'Configuratie van de site',
	'titre_config_langage' => 'Stel de taal in',
	'titre_configuration' => 'Configuratie van de site',
	'titre_configurer_preferences' => 'Configureer je voorkeuren',
	'titre_configurer_preferences_menus' => 'Configureer je menuvoorkeuren',
	'titre_conflit_edition' => 'Conflict bij de uitgave',
	'titre_connexion_ldap' => 'Opties: <b>Je LDAP-verbinding</b>',
	'titre_groupe_mots' => 'TREFWOORDENGROEP:',
	'titre_identite_site' => 'Identiteit van de site',
	'titre_langue_article' => 'Taal van het artikel',
	'titre_langue_rubrique' => 'Taal van de rubriek',
	'titre_langue_trad_article' => 'TAAL EN VERTALINGEN VAN HET ARTIKEL',
	'titre_les_articles' => 'ARTIKELEN',
	'titre_messagerie_agenda' => 'Boodschappen en agenda',
	'titre_naviguer_dans_le_site' => 'Bezoek de site...',
	'titre_nouvelle_rubrique' => 'Nieuwe rubriek',
	'titre_numero_rubrique' => 'RUBRIEKNUMMER:',
	'titre_page_articles_edit' => 'Wijzigen: @titre@',
	'titre_page_articles_page' => 'Artikelen',
	'titre_page_articles_tous' => 'Volledige site',
	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Websiteconfiguratie',
	'titre_page_delete_all' => 'Volledige en onomkeerbare verwijdering',
	'titre_page_recherche' => 'Zoekresultaat voor @recherche@ ',
	'titre_page_statistiques_referers' => 'Statistieken (per referer)',
	'titre_page_upgrade' => 'Bijwerken van SPIP',
	'titre_preference_menus_favoris' => 'Favoriete menu’s',
	'titre_publication_articles_post_dates' => 'Publicatie van postgedateerde artikelen',
	'titre_reparation' => 'Herstel',
	'titre_suivi_petition' => 'Opvolging van petities',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Alle versies van dit artikel:',
	'trad_delier' => 'Niet meer aan deze vertalingen koppelen',
	'trad_lier' => 'Dit artikel is een vertaling van artikelnummer:',
	'trad_new' => 'Een nieuwe vertaling schrijven',

	// U
	'utf8_convert_erreur_orig' => 'Fout : de karakterset @charset@ wordt niet ondersteund.',

	// V
	'version' => 'Versie:',
];
